package com.hzya.frame.plugin.a8bill.plugin;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.a8bill.dao.IPayBillPluginInitializerDao;
import com.hzya.frame.plugin.a8bill.entity.PayBillEntity;
import com.hzya.frame.plugin.a8bill.service.INingboBankPluginService;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import javax.annotation.Resource;
import java.nio.charset.StandardCharsets;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * @Description
 * @Author xiangerlin
 * @Date 2024/7/29 11:08
 **/
public class NingboBankPayPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    private INingboBankPluginService ningboBankPluginService;
    @Resource
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;
    @Autowired
    private IPayBillPluginInitializerDao payBillDao;

    @Value("${OA.data_source_code}")
    private String oa_data_source_code;
    /***
     * 插件初始化方法
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-02 10:48
     * @Param []
     * @return void
     **/
    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    /****
     * 插件销毁方法
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    /****
     * 插件的ID
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginId() {
        return "NingboBankPayPlugin";
    }

    /****
     * 插件的名称
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginName() {
        return "宁波银行转账插件";
    }

    /****
     * 插件的显示值
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginLabel() {
        return "宁波银行转账插件";
    }

    /***
     * 插件类型 1、场景插件
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-02 14:01
     * @Param []
     * @return java.lang.String
     **/
    @Override
    public String getPluginType() {
        return "1";
    }

    /***
     * 执行业务代码
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-07 11:20
     * @param requestJson  执行业务代码的参数
     * @return void
     **/
    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        JSONObject requestJsonObj  = JSON.parseObject(requestJson.toString(),JSONObject.class);
        String interId = requestJsonObj.getString("integration_task_living_details_id");
        IntegrationTaskLivingDetailsEntity oldMsg = new IntegrationTaskLivingDetailsEntity();
        if(StrUtil.isNotEmpty(interId)){
            oldMsg = taskLivingDetailsService.get(interId);
        }
        String rootAppPk = oldMsg.getRootAppPk();

        try {
            StringBuffer sb = new StringBuffer();
            if(StrUtil.isNotEmpty(rootAppPk)){
                String code = requestJson.getString("code");
                sb.append(" and id = '"+rootAppPk+"'");
            }else{
                sb.append(" and payState is null");
            }

            PayBillEntity oaBillEntity = new PayBillEntity();
            oaBillEntity.setDataSourceCode(oa_data_source_code);
            StringBuffer stringBuffer = new StringBuffer();

            //备用金申请单
            stringBuffer.append("select * from v_hzya_pay where 1=1 " );
            stringBuffer.append(sb.toString());
            List<HashMap<String, Object>> hashMaps = payBillDao.getOaBillData(stringBuffer.toString(),oaBillEntity);
            if(CollectionUtils.isNotEmpty(hashMaps)){
                for (HashMap<String, Object> hashMap : hashMaps) {
                    JSONObject main = new JSONObject();
                    for(String key:hashMap.keySet()) {
                        main.put(key, hashMap.get(key));
                    }
                    logger.info("获取到付款单的数据"+main.toString());
                    String result = ningboBankPluginService.executeEsb(main.toString(),"8000360000");
                    logger.info("推送宁波银行的返回结果"+result);
                    IntegrationTaskLivingDetailsEntity logDetails = new IntegrationTaskLivingDetailsEntity();
                    logDetails.setRootAppPk(main.getString("id"));
                    logDetails.setRootAppBill(main.getString("serialNo"));
                    logDetails.setNewTransmitInfo(result);
                    logDetails.setNewPushDate(new Date());
                    logDetails.setRootAppNewData(JSON.toJSONString(main));
                    logDetails.setPluginId("NingboBankPayPlugin");
                    JSONObject resultObj = JSON.parseObject(result);
                    String attribute = resultObj.getString("attribute");
                    boolean flag = resultObj.getBoolean("flag");
                    String subState = "";
                    String fieldName = main.getString("fieldName");
                    String tableName = main.getString("tableName");
                    String payMsg = main.getString("payMsg");
//                    String subMsg = main.getString("subMsg");
                    String str = "";
                    String sync_flag = "";
                    try {
                        if(StrUtil.isEmpty(interId)){// 银行状态 1支付中 2 支付失败 null 未提交支付 0支付成功
                            logDetails.setCreate_time(new Date());
                            logDetails.setModify_time(new Date());
                            if(flag){
                                subState = "1";
                                sync_flag = " ,"+payMsg+" = '支付中'";
                                taskLivingDetailsService.saveLogToSuccess(logDetails);
                            }else{
                                subState = "2";
                                String resMsg = JSONObject.parseObject(attribute).getString("retMsg");
                                sync_flag = " ,"+payMsg+" = '"+resMsg+"'";
                                taskLivingDetailsService.saveLogToFail(logDetails);
                            }
                        }else{
                            logDetails.setId(interId);
                            logDetails.setModify_time(new Date());
                            if(flag){
                                subState = "1";
                                sync_flag = " ,"+payMsg+" = '支付中'";
                                taskLivingDetailsService.saveLogFailToSuccess(logDetails);
                            }else{
                                subState = "2";
                                String resMsg = JSONObject.parseObject(attribute).getString("retMsg");
                                sync_flag = " ,"+payMsg+" = '"+resMsg+"'";
                                taskLivingDetailsService.updateLogFailToSuccess(logDetails);
                            }
                        }

                        str = "update "+tableName+" set " + fieldName + "= '" +subState+"'" +sync_flag+"where id = '"+main.getString("id")+"'";
                    } catch (Exception e) {
                        subState = "N";
                        str = "update "+tableName+" set " + fieldName + "= '" +subState+"'" +payMsg+" = '"+attribute+"' "+"where id = '"+main.getString("id")+"'";
                        logger.info("保存日志失败"+e.getMessage());
                        oaBillEntity.setSql(str);
                        payBillDao.updateStateForId(str,oaBillEntity);
                        e.printStackTrace();
                    }
                    //修改推送状态，防止重复推送
                    oaBillEntity.setSql(str);
                    payBillDao.updateStateForId(str,oaBillEntity);
                }
            }
        } catch (Exception e) {
            logger.info("获取OA数据失败"+e.getMessage());
            e.printStackTrace();
        }
        return new JsonResultEntity("成功",true,new JsonResultEntity());
    }
}
