package com.hzya.frame.plugin.a8bill.plugin;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.ningboBankTreasury.enums.PayStatusEnum;
import com.hzya.frame.plugin.a8bill.dao.IPayBillPluginInitializerDao;
import com.hzya.frame.plugin.a8bill.entity.PayBillEntity;
import com.hzya.frame.plugin.a8bill.service.INingboBankPluginService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description 宁波银行 单笔付款交易结果查询
 * @Author xiangerlin
 * @Date 2024/7/29 16:59
 **/
public class NingboBankPayResultPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(getClass());
    @Value("${OA.data_source_code}")
    private String oa_data_source_code;
    @Autowired
    private IPayBillPluginInitializerDao payBillDao;
    @Autowired
    private INingboBankPluginService ningboBankPluginService;
    /***
     * 插件初始化方法
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-02 10:48
     * @Param []
     * @return void
     **/
    @Override
    public void initialize() {

        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    /****
     * 插件销毁方法
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    /****
     * 插件的ID
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginId() {
        return "NingboBankPayResultPlugin";
    }

    /****
     * 插件的名称
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginName() {
        return "宁波银行转账结果查询插件";
    }

    /****
     * 插件的显示值
     * @author 👻👻👻👻👻👻👻👻 gjh
     * @date 2023-08-02 10:48
     * @return void
     **/
    @Override
    public String getPluginLabel() {
        return "宁波银行转账结果查询插件";
    }

    /***
     * 插件类型 1、场景插件
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-02 14:01
     * @Param []
     * @return java.lang.String
     **/
    @Override
    public String getPluginType() {
        return "1";
    }

    /***
     * 执行业务代码
     * @Author 👻👻👻👻👻👻👻👻 gjh
     * @Date 2023-08-07 11:20
     * @param requestJson  执行业务代码的参数
     * @return void
     **/
    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        PayBillEntity oaBillEntity = new PayBillEntity();
        oaBillEntity.setDataSourceCode(oa_data_source_code);
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("select * from v_hzya_pay where payState ='1'");
        try {
            List<HashMap<String, Object>> hashMaps = payBillDao.getOaBillData(stringBuffer.toString(),oaBillEntity);
            if(CollectionUtils.isNotEmpty(hashMaps)){
                for (HashMap<String, Object> hashMap : hashMaps) {
                    JSONObject main = new JSONObject();
                    for(String key:hashMap.keySet()) {
                        main.put(key, hashMap.get(key));
                    }
                    String tableName = main.getString("tableName");
                    String fieldName = main.getString("fieldName");
                    String payDate = main.getString("payDate");
                    String payMsg = main.getString("payMsg");
                    try {

                        logger.info("获取到付款单状态的数据"+main.toString());
                        JSONObject reMain = new JSONObject();
                        reMain.put("serialNo",main.getString("serialNo"));
                        String result = ningboBankPluginService.executeEsb(reMain.toString(),"8000360001");
                        logger.info("获取付款状态结果"+result);

                        JSONObject resultObj = JSON.parseObject(result);
                        JSONObject attribute = resultObj.getJSONObject("attribute");
                        boolean flag = resultObj.getBoolean("flag");

                        StringBuffer sb = new StringBuffer();
                        sb.append("update "+tableName);
                        if(flag){
                            JSONObject data = attribute.getJSONObject("Data");
                            JSONObject transferDtl = data.getJSONObject("transferDtl");
                            String status = transferDtl.getString("status");
                            String msg = PayStatusEnum.getByCode(status);
                            if(StrUtil.isEmpty(msg)){
                                msg  ="未知交易状态，请联系管理员查证";
                                sb.append(" set "+payMsg+" = '"+msg+"'");
                                sb.append(" , "+fieldName+" = '2'");
                            }
                            sb.append(" set "+payMsg+" = '"+msg+"'");
                            //收否最终态
                            if(PayStatusEnum.isFinally(status)){
                                sb.append(" , "+fieldName+" = '0'");
                                String payDateStr = DateUtil.now();
                                sb.append(" , "+payDate+" = '"+payDateStr+"'");
                            }
                        }else {
                            sb.append(" set "+payMsg+" = '查询失败，请联系管理员'");
                            sb.append(" ,"+fieldName+" = '2'");

                        }
                        sb.append(" where id = '"+main.getString("id")+"'");
                        //修改推送状态，防止重复推送
                        oaBillEntity.setSql(sb.toString());
                        payBillDao.updateStateForId(sb.toString(),oaBillEntity);
                    } catch (Exception e) {
                        StringBuffer sb = new StringBuffer();
                        sb.append("update "+tableName );
                        sb.append(" set "+payMsg+" = '获取交易状态失败'");
                        sb.append(" , "+fieldName+" = '2'");
                        sb.append(" where id = '"+main.getString("id")+"'");
                        logger.info("获取交易状态失败，更新交易信息为失败状态，后续不在查询");
                        e.printStackTrace();
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return new JsonResultEntity("成功",true,new JsonResultEntity());
    }
}
